<?php

// src/Controller/DataImport.php
// Grab data from transfer app

namespace App\Controller\Routes\Front;

use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use App\Service\Auth;
use App\Service\Render;
use App\Service\HandleLocations;

class Index extends AbstractController
{
    /**
     * @Route("/", name="index")
     */
    public function showIndex(Request $request, Auth $auth, Render $render, HandleLocations $locations): Response
    {
        $list = $locations->getActiveLocations();
        return $render->page(["count" => count($list)], "This is The Bad Space", "front/index.twig");
    }

    /**
     * @Route("/about", name="about")
     */
    public function showAbout(
        Request $request,
        Auth $auth,
        Render $render,
        HandleLocations $locations
    ): Response {
        return $render->page([], "About The Bad Space", "front/about.twig");
    }

    /**
     * @Route("/listings/page/{pageNum}", name="listings")
     */
    public function showListing(
        Request $request,
        Auth $auth,
        Render $render,
        HandleLocations $locations,
        string $pageNum
    ): Response {
        $list = $locations->getLocationsPage($pageNum, "true");
        return $render->page(["list" => $list, "page" => $pageNum], "About The Bad Space", "front/listing.twig");
    }
}
